@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: CmdExec.h,v 1.39 2001/03/13 08:41:42 lav Exp $ */
+/* $Id: CmdExec.h,v 1.40 2001/05/10 14:44:23 lav Exp $ */
 
 #ifndef CMDEXEC_H
 #define CMDEXEC_H
@@ -202,6 +202,11 @@ public:
 	 top_level=true;
 	 Reconfig(0);
       }
+   void SetStatusLine(StatusLine *s)
+      {
+	 Delete(status_line);
+	 status_line=s;
+      }
 
    static void RegisterCommand(const char *name,cmd_creator_t creator,
       const char *short_name=0,const char *long_name=0);
