@@ -1,7 +1,7 @@
 /*
  * lftp and utils
  *
- * Copyright (c) 1996-2000 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2001 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: MirrorJob.cc,v 1.60 2000/10/19 12:18:29 lav Exp $ */
+/* $Id: MirrorJob.cc,v 1.62 2001/04/17 09:52:05 lav Exp $ */
 
 #include <config.h>
 
@@ -82,21 +82,21 @@ void  MirrorJob::PrintStatus(int v)
 
 final:
    if(dirs>0)
-      printf(plural(N_("%sTotal: %d director$y|ies$, %d file$|s$, %d symlink$|s$\n"),
+      printf(plural("%sTotal: %d director$y|ies$, %d file$|s$, %d symlink$|s$\n",
 		     dirs,tot_files,tot_symlinks),
 	 tab,dirs,tot_files,tot_symlinks);
    if(new_files || new_symlinks)
-      printf(plural(N_("%sNew: %d file$|s$, %d symlink$|s$\n"),
+      printf(plural("%sNew: %d file$|s$, %d symlink$|s$\n",
 		     new_files,new_symlinks),
 	 tab,new_files,new_symlinks);
    if(mod_files || mod_symlinks)
-      printf(plural(N_("%sModified: %d file$|s$, %d symlink$|s$\n"),
+      printf(plural("%sModified: %d file$|s$, %d symlink$|s$\n",
 		     mod_files,mod_symlinks),
 	 tab,mod_files,mod_symlinks);
    if(del_dirs || del_files || del_symlinks)
       printf(plural(flags&DELETE ?
-	       N_("%sRemoved: %d director$y|ies$, %d file$|s$, %d symlink$|s$\n")
-	      :N_("%sTo be removed: %d director$y|ies$, %d file$|s$, %d symlink$|s$\n"),
+	       "%sRemoved: %d director$y|ies$, %d file$|s$, %d symlink$|s$\n"
+	      :"%sTo be removed: %d director$y|ies$, %d file$|s$, %d symlink$|s$\n",
 	      del_dirs,del_files,del_symlinks),
 	 tab,del_dirs,del_files,del_symlinks);
    return;
@@ -1062,7 +1062,7 @@ CMD(mirror)
       {0}
    };
 
-   char cwd[2*1024];
+   char *cwd;
    const char *rcwd;
    int opt;
    int	 flags=0;
@@ -1186,7 +1186,8 @@ CMD(mirror)
       }
    }
 
-   if(getcwd(cwd,sizeof(cwd)/2)==0)
+   cwd=string_alloca(1024);
+   if(getcwd(cwd,1024)==0)
    {
       perror("getcwd()");
       return 0;
@@ -1201,11 +1202,13 @@ CMD(mirror)
       else
       {
 	 if(arg[0]=='/')
-	    strcpy(cwd,arg);
+	    cwd=arg;
 	 else
 	 {
-	    strcat(cwd,"/");
-	    strcat(cwd,arg);
+	    char *cwd1=alloca_strdup2(cwd,strlen(arg)+1);
+	    strcat(cwd1,"/");
+	    strcat(cwd1,arg);
+	    cwd=cwd1;
 	 }
 	 rcwd=args->getnext();
 	 if(!rcwd)
@@ -1227,25 +1230,32 @@ CMD(mirror)
 	 rcwd=".";
       else
       {
-	 strcat(cwd,"/");
 	 char *arg=args->getnext();
 	 if(arg)
 	 {
 	    if(arg[0]=='/')
-	       strcpy(cwd,arg);
+	       cwd=arg;
 	    else
-	       strcat(cwd,arg);
+	    {
+	       char *cwd1=alloca_strdup2(cwd,strlen(arg)+1);
+	       strcat(cwd1,"/");
+	       strcat(cwd1,arg);
+	       cwd=cwd1;
+	    }
 	    if(create_directories(arg)==-1)
 	       return 0;
 	 }
 	 else
 	 {
-	    int len=strlen(cwd);
 	    const char *base=basename_ptr(rcwd);
 	    if(base[0]!='/')
 	    {
-	       strcat(cwd,base);
-	       if(create_directories(cwd+len)==-1)
+	       int len=strlen(cwd);
+	       char *cwd1=alloca_strdup2(cwd,strlen(base)+1);
+	       strcat(cwd1,"/");
+	       strcat(cwd1,base);
+	       cwd=cwd1;
+	       if(create_directories(cwd+len+1)==-1)
 		  return 0;
 	    }
 	 }
@@ -1304,7 +1314,8 @@ mode_t MirrorJob::get_mode_mask()
 
 #include "modconfig.h"
 #ifdef MODULE_CMD_MIRROR
-CDECL void module_init()
+CDECL void module_init();
+void module_init()
 {
    CmdExec::RegisterCommand("mirror",cmd_mirror);
 }
