@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: NetAccess.cc,v 1.38 2001/02/13 16:50:22 lav Exp $ */
+/* $Id: NetAccess.cc,v 1.39 2001/05/04 13:58:55 lav Exp $ */
 
 #include <config.h>
 
@@ -258,13 +258,18 @@ bool NetAccess::NoProxy(const char *hostname)
    return false;
 }
 
+void NetAccess::HandleTimeout()
+{
+   DebugPrint("**** ",_("Timeout - reconnecting"),0);
+   Disconnect();
+   event_time=now;
+}
+
 bool NetAccess::CheckTimeout()
 {
    if(now-event_time>=timeout)
    {
-      DebugPrint("**** ",_("Timeout - reconnecting"),0);
-      Disconnect();
-      event_time=now;
+      HandleTimeout();
       return(true);
    }
    TimeoutS(timeout-(now-event_time));
