@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: ProcWait.cc,v 1.9 2000/02/04 12:26:32 lav Exp $ */
+/* $Id: ProcWait.cc,v 1.10 2001/02/03 11:39:00 lav Exp $ */
 
 #include <config.h>
 #include <sys/wait.h>
@@ -49,7 +49,7 @@ int ProcWait::Do()
    {
       if(status!=RUNNING)
 	 return MOVED;
-      if(errno==EINTR || errno==EAGAIN)
+      if(E_RETRY(errno))
 	 goto leave;
       // waitpid failed, check the process existence
       if(kill(pid,0)==-1)
