@@ -1,7 +1,7 @@
 /*
  * lftp and utils
  *
- * Copyright (c) 1996-1997 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2001 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: ResMgr.cc,v 1.27 2000/10/03 11:21:59 lav Exp $ */
+/* $Id: ResMgr.cc,v 1.29 2001/05/10 14:44:24 lav Exp $ */
 
 #include <config.h>
 
@@ -501,6 +501,39 @@ ResDecl::ResDecl(const char *a_name,const char *a_defvalue,
       ResMgr::Set(name,0,defvalue);
 #endif
 }
+ResDecl::~ResDecl()
+{
+   for(ResDecl **scan=&ResMgr::type_chain; *scan; scan=&(*scan)->next)
+   {
+      if(*scan==this)
+      {
+	 *scan=this->next;
+	 break;
+      }
+   }
+
+   // remove all resources of this type
+   bool modified=false;
+   ResMgr::Resource **scan=&ResMgr::chain;
+   while(*scan)
+   {
+      if((*scan)->type==this)
+      {
+	 ResMgr::Resource *to_free=*scan;
+	 *scan=(*scan)->next;
+	 delete to_free;
+	 modified=true;
+      }
+      else
+      {
+	 scan=&(*scan)->next;
+      }
+   }
+#if 0 // this makes trouble at exit.
+   if(modified)
+      SMTask::ReconfigAll(this->name);
+#endif
+}
 
 #define MINUTE (60)
 #define HOUR   (60*MINUTE)
