@@ -1,7 +1,7 @@
 /*
  * lftp and utils
  *
- * Copyright (c) 1996-1997 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2001 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: ResMgr.h,v 1.19 2000/08/23 23:17:46 lav Exp $ */
+/* $Id: ResMgr.h,v 1.20 2001/04/04 07:22:11 lav Exp $ */
 
 #ifndef RESMGR_H
 #define RESMGR_H
@@ -41,6 +41,7 @@ public:
    class Resource
    {
       friend class ResMgr;
+      friend class ResDecl;
 
       const ResDecl *type;
       char *value;
@@ -112,6 +113,7 @@ public:
 
    ResDecl(const char *name,const char *defvalue,
 	   ResValValid *val_valid,ResClValid *closure_valid=0);
+   ~ResDecl();
 
    ResValue Query(const char *closure);
 };
