@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: StatusLine.h,v 1.5 2000/01/27 17:07:54 lav Exp $ */
+/* $Id: StatusLine.h,v 1.6 2001/03/13 08:41:42 lav Exp $ */
 
 #ifndef STATUSLINE_H
 #define STATUSLINE_H
@@ -38,16 +38,19 @@ class StatusLine : public SMTask
    bool	not_term;
    time_t update_time;
    char to_be_shown[0x800];
+   char def_title[0x800];
    bool update_delayed;
    void update(char *);
    int LastWidth;
 
 protected:
    ~StatusLine();
-
+   void WriteTitle(const char *s, int fd) const;
+	   
 public:
    int GetWidth();
    int GetWidthDelayed() { return LastWidth; }
+   void DefaultTitle(const char *s);
    void Show(const char *f,...) PRINTF_LIKE(2,3);
    void WriteLine(const char *f,...) PRINTF_LIKE(2,3);
    void Clear();
