@@ -1,7 +1,7 @@
 /*
  * lftp - file transfer program
  *
- * Copyright (c) 1999 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1999-2001 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: lftp_rl.h,v 1.3 2000/02/12 19:24:39 lav Exp $ */
+/* $Id: lftp_rl.h,v 1.5 2001/04/18 10:25:24 lav Exp $ */
 
 #ifndef LFTP_RL_H
 #define LFTP_RL_H
@@ -31,6 +31,21 @@ char *lftp_readline (const char *prompt);
 void lftp_add_history_nodups(const char *cmd);
 void lftp_rl_clear(void);
 void lftp_rl_redisplay_maybe(void);
+void lftp_rl_set_ignore_some_completions_function(int (*func)(char**));
+char **lftp_rl_completion_matches(const char *text,char *(*compentry)(const char *,int));
+void lftp_rl_add_defun(const char *name,int (*func)(int,int),int key);
+void lftp_rl_bind(const char *key,const char *func);
+
+void lftp_rl_init(
+   const char *readline_name,
+   char **(*attempted_completion_function)(const char *,int,int),
+   int (*getc_function)(FILE*),
+   const char *completer_quote_characters,
+   const char *completer_word_break_characters,
+   const char *filename_quote_characters,
+   char *(*filename_quoting_function)(char *,int,char *),
+   char *(*filename_dequoting_function)(char *,int),
+   int (*char_is_quoted_p)(char *,int));
 
 CDECL_END
 
